/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "File.h"
#include "FileList.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomFile.h"
#include "gdom/GdomFileList.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomFile.h"
#include "gdom/PrivateGdomFileList.h"
#include "gdom/PrivateIntGdomFile.h"
#include "gdom/PrivateIntGdomFileList.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::FileList* obj)
{
    return WebCore::cacheDOMObject<WebCore::FileList, GDOMFileList>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMFileList::GDOMFileList(PassRefPtr<WebCore::FileList> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMFileList::~GDOMFileList()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

GdomFile *
gdom_file_list_item (GdomFileList *thiz, gulong index)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::FileList * item = (gdom_file_list_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::File> g_res = WTF::getPtr(item->item(index));
    GdomFile * res = static_cast<GdomFile *>(WebCore::toGDOM(g_res.get()));
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "FileList.h"
#include <gdom/GdomFileList.h>
#include <gdom/PrivateGdomFileList.h>
#include <gdom/PrivateIntGdomFileList.h>
#include <gdom/GdomFileListprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomFileList, gdom_file_list, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomFileListPrivate {
    class WebCore::FileList *item;
};

#define GDOM_FILE_LIST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_FILE_LIST, GdomFileListPrivate))
*/
G_END_DECLS
WebCore::FileList *
gdom_file_list_get_private(GdomFileList *request)
{
    GDOMFileList *res;
    res = static_cast<GDOMFileList*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::FileList*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_LENGTH,
};


static void gdom_file_list_finalize(GObject* object)
{
    /*GdomFileList* request = GDOM_FILE_LIST(object);*/
    /*GdomFileListPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_file_list_parent_class)->finalize(object);
}

static void gdom_file_list__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomFileList *self = GDOM_FILE_LIST(object);
    WebCore::FileList * gself = (gdom_file_list_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_file_list__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomFileList *self = GDOM_FILE_LIST(object);
    WebCore::FileList * gself = (gdom_file_list_get_private(self));
    switch (prop_id) {
    case PROP_LENGTH:
    {
         g_value_set_ulong (value, gself->length());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_file_list_class_init(GdomFileListClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_file_list_finalize;
    g_klass->set_property = gdom_file_list__set_property_fn;
    g_klass->get_property = gdom_file_list__get_property_fn;

    g_object_class_install_property (g_klass, PROP_LENGTH,
            g_param_spec_ulong ("length", /* name */
                "file_list_length", /* short description */
                "read-only  gulong FileList.length", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomFileListPrivate));*/
}

static void gdom_file_list_init(GdomFileList* request)
{
    /*GdomFileListPrivate* priv = GDOM_FILE_LIST_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

